Crate zoi_plugins

Crate zoi_plugins 

Plugin management system for Zoi.

This crate provides the PluginManager which handles loading and executing Lua plugins that extend Zoi’s functionality. It also includes support for extensions that can modify registry configurations.

Modules

extension
Registry extension management.

Structs

PluginManager
Orchestrates Zoi’s extensibility via global Lua plugins.

Functions

get_plugin_dir
Returns the path to the Zoi plugin directory.