Module extension

Module extension 

Registry extension management.

Functions

add
Installs an extension, applying its declared changes to the system and registry configuration.
remove
Uninstalls an extension and reverts all changes it made to the system and configuration.