get_plugin_dir

Function get_plugin_dir 

pub fn get_plugin_dir() -> Result<PathBuf>
Returns the path to the Zoi plugin directory.

Errors

Returns an error if the user home directory cannot be found or if the plugin directory cannot be created.